# tree-sitter-clingo [![Build Status](https://github.com/potassco/tree-sitter-clingo/workflows/CI%20test/badge.svg)](https://github.com/potassco/tree-sitter-clingo) [![Latest Version](https://img.shields.io/crates/v/tree-sitter-clingo.svg)](https://crates.io/crates/tree-sitter-clingo) [![Rust Documentation](https://img.shields.io/badge/api-rustdoc-blue.svg)](https://docs.rs/tree-sitter-clingo)

Clingo grammar for [tree-sitter](https://github.com/tree-sitter/tree-sitter)
